pub fn var_decl_info(node: &SyntaxNode) -> Option<VarDeclInfo>Expand description
Returns the declaration kind and name from a NodeVarDecl.
For “var x”, “global T x”: name is the first identifier after the keyword.
For typed form “Array
pub fn var_decl_info(node: &SyntaxNode) -> Option<VarDeclInfo>Returns the declaration kind and name from a NodeVarDecl.
For “var x”, “global T x”: name is the first identifier after the keyword.
For typed form “Array