pub fn analyze_with_include_tree(
tree: &IncludeTree,
signature_roots: &[SyntaxNode],
) -> AnalysisResultExpand description
Analyze the main file of an include tree: seed scope from included files and signatures, then analyze the main AST.
pub fn analyze_with_include_tree(
tree: &IncludeTree,
signature_roots: &[SyntaxNode],
) -> AnalysisResultAnalyze the main file of an include tree: seed scope from included files and signatures, then analyze the main AST.