pub fn format_syntax_tree(
root: &SyntaxNode,
options: &TreeDisplayOptions,
) -> StringExpand description
Format a syntax tree starting at root as a multi-line string.
Uses LeekScript kind names for node and token labels.
pub fn format_syntax_tree(
root: &SyntaxNode,
options: &TreeDisplayOptions,
) -> StringFormat a syntax tree starting at root as a multi-line string.
Uses LeekScript kind names for node and token labels.