parse_recovering

Function parse_recovering 

pub fn parse_recovering(
    source: &str,
) -> Result<ParseOutput, (ParseOutput, ParseError)>
Parse in recovering mode: on failure, returns the partial output and the error.

Returns Ok(out) on full success; Err((partial, e)) on failure, with partial containing tree events and consumed up to the error position. Use partial.syntax_root(source.as_bytes()) to try to build a partial tree (may be None if events are not well-nested). Use for IDE or multi-error reporting.