pub fn load_formatter_options_from_file(path: &Path) -> Option<FormatterOptions>Expand description
Load formatter options from a single config file (e.g. .leekfmt.toml) with a top-level [format] section.
pub fn load_formatter_options_from_file(path: &Path) -> Option<FormatterOptions>Load formatter options from a single config file (e.g. .leekfmt.toml) with a top-level [format] section.